@@ -28,25 +28,40 @@
 
 This AWS Solutions Construct implements an Amazon API Gateway REST API connected to Amazon DynamoDB table.
 
-Here is a minimal deployable pattern definition in Typescript:
+Here is a minimal deployable pattern definition in
+
+Typescript:
 
 ```python
+import { Construct } from 'constructs';
+import { Stack, StackProps } from 'aws-cdk-lib';
 import { ApiGatewayToDynamoDBProps, ApiGatewayToDynamoDB } from "@aws-solutions-constructs/aws-apigateway-dynamodb";
 
 new ApiGatewayToDynamoDB(this, 'test-api-gateway-dynamodb-default', {});
 ```
 
-## Initializer
+Python
 
-```text
-new ApiGatewayToDynamoDB(scope: Construct, id: string, props: ApiGatewayToDynamoDBProps);
+```python
+from aws_solutions_constructs.aws_apigateway_dynamodb import ApiGatewayToDynamoDB
+from aws_cdk import Stack
+from constructs import Construct
+
+ApiGatewayToDynamoDB(self, 'test-api-gateway-dynamodb-default')
 ```
 
-*Parameters*
+Java
 
-* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
-* id `string`
-* props [`ApiGatewayToDynamoDBProps`](#pattern-construct-props)
+```java
+import software.constructs.Construct;
+
+import software.amazon.awscdk.Stack;
+import software.amazon.awscdk.StackProps;
+import software.amazon.awsconstructs.services.apigatewaydynamodb.*;
+
+new ApiGatewayToDynamoDB(this, "test-api-gateway-dynamodb-default", new ApiGatewayToDynamoDBProps.Builder()
+        .build());
+```
 
 ## Pattern Construct Props
 
